@@ -34,8 +34,10 @@ from __future__ import absolute_import
 
 import os
 
-import mock
-from mock import patch
+try:
+    from unittest.mock import Mock, patch
+except ImportError:
+    from mock import Mock, patch
 
 
 class TrueOs():
@@ -108,10 +110,20 @@ def test_LsbDetect():
     else:
         import platform as distro
 
-    distro.linux_distribution = mock.Mock()
-    distro.linux_distribution.return_value = ('Ubuntu', '10.04', 'lucid')
-    distro.dist = mock.Mock()
-    distro.dist.return_value = ('Ubuntu', '10.04', 'lucid')
+    # Mock different interfaces based on the module used.
+    if distro.__name__ == 'distro':
+        distro.id = Mock()
+        distro.id.return_value = 'Ubuntu'
+        distro.version = Mock()
+        distro.version.return_value = '10.04'
+        distro.codename = Mock()
+        distro.codename.return_value = 'lucid'
+    elif hasattr(distro, 'linux_distribution'):
+        distro.linux_distribution = Mock()
+        distro.linux_distribution.return_value = ('Ubuntu', '10.04', 'lucid')
+    elif hasattr(distro, 'dist'):
+        distro.dist = Mock()
+        distro.dist.return_value = ('Ubuntu', '10.04', 'lucid')
 
     detect = LsbDetect('Ubuntu')
     assert detect.is_os(), "should be Ubuntu"
@@ -391,7 +403,7 @@ def test_OsDetector():
 def test_tripwire_uname_get_machine():
     from rospkg.os_detect import uname_get_machine
     retval = uname_get_machine()
-    assert retval in [None, 'aarch64', 'armv7l', 'armv8l', 'i386', 'i686', 'ppc', 'ppc64', 'ppc64le', 's390', 's390x', 'x86_64']
+    assert retval in [None, 'aarch64', 'armv7l', 'armv8l', 'i386', 'i686', 'ppc', 'ppc64', 'ppc64le', 'riscv32', 'riscv64', 's390', 's390x', 'x86_64']
 
 
 def test_tripwire_rhel():
